@@ -4,26 +4,11 @@ from pathlib import Path
 
 import pyproj
 from pyproj.crs import ProjectedCRS
-from pyproj.crs.coordinate_operation import AzumuthalEquidistantConversion
+from pyproj.crs.coordinate_operation import AzimuthalEquidistantConversion
 import geopandas as gpd
 import logging
-
-# osgeo safe imports
-try:
-    import osr
-except ModuleNotFoundError as e:
-    try:
-        from osgeo import osr
-    except ModuleNotFoundError:
-        raise e
-
-try:
-    import ogr
-except ModuleNotFoundError as e:
-    try:
-        from osgeo import ogr
-    except ModuleNotFoundError:
-        raise e
+from osgeo import osr
+from osgeo import ogr
 
 from shapely.ops import transform
 from shapely.wkt import loads
@@ -31,8 +16,6 @@ from shapely.geometry import Point, Polygon, mapping, shape
 from shapely.errors import WKTReadingError
 from fiona import collection
 from fiona.crs import from_epsg
-# from pyproj.exceptions import CRSError as projCRSError
-# from fiona.errors import DriverError, CRSError
 
 logger = logging.getLogger(__name__)
 
@@ -62,28 +45,28 @@ def aoi_to_wkt(aoi):
         # see if aoi is an ISO3 country code
         try:
             # let's check if it is a shapely readable WKT
-            world = gpd.read_file(gpd.datasets.get_path('naturalearth_lowres'))
-            aoi_wkt = world['geometry'][world['iso_a3'] == aoi].values[0].to_wkt()
+            world = gpd.read_file(gpd.datasets.get_path("naturalearth_lowres"))
+            aoi_wkt = world["geometry"][world["iso_a3"] == aoi].values[0].wkt
 
         except IndexError:
             # see if it is a Geovector file
             if Path(aoi).exists():
                 try:
                     gdf = gpd.GeoDataFrame.from_file(aoi)
-                    if gdf.crs != 'epsg:4326':
+                    if gdf.crs != "epsg:4326":
                         try:
-                            gdf = gdf.geometry.to_crs('epsg:4326')
-                        except:
-                            raise ValueError('No valid OST AOI definition.')
+                            gdf = gdf.geometry.to_crs("epsg:4326")
+                        except Exception:
+                            raise ValueError("No valid OST AOI definition.")
                     # return AOI as single vector object
                     aoi_wkt = str(gdf.geometry.unary_union)
-                except:
+                except Exception:
                     # give up
-                    raise ValueError('No valid OST AOI definition.')
+                    raise ValueError("No valid OST AOI definition.")
 
             else:
                 # give up
-                raise ValueError('No valid OST AOI definition.')
+                raise ValueError("No valid OST AOI definition.")
 
     return aoi_wkt
 
@@ -95,7 +78,7 @@ def get_epsg(prjfile):
     :return:
     """
 
-    prj_file = open(prjfile, 'r')
+    prj_file = open(prjfile, "r")
     prj_txt = prj_file.read()
     srs = osr.SpatialReference()
     srs.ImportFromESRI([prj_txt])
@@ -111,18 +94,24 @@ def get_proj4(prjfile):
     :return:
     """
 
-    prj_file = open(prjfile, 'r')
+    prj_file = open(prjfile, "r")
     prj_string = prj_file.read()
 
     # Lambert error
-    if '\"Lambert_Conformal_Conic\"' in prj_string:
+    if '"Lambert_Conformal_Conic"' in prj_string:
 
-        print(' ERROR: It seems you used an ESRI generated shapefile'
-              ' with Lambert Conformal Conic projection. ')
-        print(' This one is not compatible with Open Standard OGR/GDAL'
-              ' tools used here. ')
-        print(' Reproject your shapefile to a standard Lat/Long projection'
-              ' and try again')
+        print(
+            " ERROR: It seems you used an ESRI generated shapefile"
+            " with Lambert Conformal Conic projection. "
+        )
+        print(
+            " This one is not compatible with Open Standard OGR/GDAL"
+            " tools used here. "
+        )
+        print(
+            " Reproject your shapefile to a standard Lat/Long projection"
+            " and try again"
+        )
         exit(1)
 
     srs = osr.SpatialReference()
@@ -138,8 +127,8 @@ def epsg_to_wkt_projection(epsg_code):
     """
 
     spatial_ref = osr.SpatialReference()
-    spatial_ref.ImportFromEPSG(epsg_code)  
-            
+    spatial_ref.ImportFromEPSG(epsg_code)
+
     return spatial_ref.ExpotToWkt()
 
 
@@ -162,12 +151,11 @@ def reproject_geometry(geom, inproj4, out_epsg):
     spatial_ref_out.ImportFromEPSG(int(out_epsg))
 
     # create the CoordinateTransformation
-    coord_transform = osr.CoordinateTransformation(spatial_ref_in,
-                                                   spatial_ref_out)
+    coord_transform = osr.CoordinateTransformation(spatial_ref_in, spatial_ref_out)
     try:
         geom.Transform(coord_transform)
-    except:
-        raise RuntimeError(' ERROR: Not able to transform the geometry')
+    except Exception:
+        raise RuntimeError(" ERROR: Not able to transform the geometry")
 
     return geom
 
@@ -183,16 +171,12 @@ def geodesic_point_buffer(lon, lat, meters, envelope=False):
     """
 
     proj_crs = ProjectedCRS(
-        conversion=AzumuthalEquidistantConversion(float(lat), float(lon))
+        conversion=AzimuthalEquidistantConversion(float(lat), float(lon))
     )
 
-    proj_wgs84 = pyproj.Proj('EPSG:4326')
+    proj_wgs84 = pyproj.Proj("EPSG:4326")
 
-    Trans = pyproj.Transformer.from_proj(
-        proj_crs,
-        proj_wgs84,
-        always_xy=True
-    ).transform
+    Trans = pyproj.Transformer.from_proj(proj_crs, proj_wgs84, always_xy=True).transform
 
     buf = Point(0, 0).buffer(meters)  # distance in metres
 
@@ -204,9 +188,7 @@ def geodesic_point_buffer(lon, lat, meters, envelope=False):
     return geom.wkt
 
 
-def latlon_to_wkt(
-        lat, lon, buffer_degree=None, buffer_meter=None, envelope=False
-):
+def latlon_to_wkt(lat, lon, buffer_degree=None, buffer_meter=None, envelope=False):
     """A helper function to create a WKT representation of Lat/Lon pair
 
     This function takes lat and lon values and returns
@@ -232,14 +214,14 @@ def latlon_to_wkt(
     """
 
     if buffer_degree is None and buffer_meter is None:
-        aoi_wkt = f'POINT ({lon} {lat})'
+        aoi_wkt = f"POINT ({lon} {lat})"
 
     elif buffer_degree:
-        aoi_geom = loads(f'POINT ({lon} {lat})').buffer(buffer_degree)
+        aoi_geom = loads(f"POINT ({lon} {lat})").buffer(buffer_degree)
         if envelope:
             aoi_geom = aoi_geom.envelope
 
-        aoi_wkt = aoi_geom.to_wkt()
+        aoi_wkt = aoi_geom.wkt
 
     elif buffer_meter:
         aoi_wkt = geodesic_point_buffer(lon, lat, buffer_meter, envelope)
@@ -268,14 +250,14 @@ def wkt_manipulations(wkt, buffer=None, convex=False, envelope=False):
     if envelope:
         geom = geom.GetEnvelope()
         geom = ogr.CreateGeometryFromWkt(
-                    f'POLYGON (('
-                    f'{geom[1]} {geom[3]}, '
-                    f'{geom[0]} {geom[3]}, '
-                    f'{geom[0]} {geom[2]}, '
-                    f'{geom[1]} {geom[2]}, '
-                    f'{geom[1]} {geom[3]}, '
-                    f'{geom[1]} {geom[3]}'
-                    f'))'
+            f"POLYGON (("
+            f"{geom[1]} {geom[3]}, "
+            f"{geom[0]} {geom[3]}, "
+            f"{geom[0]} {geom[2]}, "
+            f"{geom[1]} {geom[2]}, "
+            f"{geom[1]} {geom[3]}, "
+            f"{geom[1]} {geom[3]}"
+            f"))"
         )
 
     return geom.ExportToWkt()
@@ -293,7 +275,7 @@ def shp_to_wkt(shapefile, buffer=None, convex=False, envelope=False):
 
     # get filepaths and proj4 string
     shpfile = os.path.abspath(shapefile)
-    prjfile = shpfile[:-4] + '.prj'
+    prjfile = shpfile[:-4] + ".prj"
     proj4 = get_proj4(prjfile)
 
     lyr_name = os.path.basename(shapefile)[:-4]
@@ -306,13 +288,12 @@ def shp_to_wkt(shapefile, buffer=None, convex=False, envelope=False):
 
     wkt = geom.ExportToWkt()
 
-    if proj4 != '+proj=longlat +datum=WGS84 +no_defs':
-        logger.info('Reprojecting AOI file to Lat/Long (WGS84)')
+    if proj4 != "+proj=longlat +datum=WGS84 +no_defs":
+        logger.info("Reprojecting AOI file to Lat/Long (WGS84)")
         wkt = reproject_geometry(wkt, proj4, 4326).ExportToWkt()
 
     # do manipulations if needed
-    wkt = wkt_manipulations(wkt, buffer=buffer, convex=convex,
-                            envelope=envelope)
+    wkt = wkt_manipulations(wkt, buffer=buffer, convex=convex, envelope=envelope)
 
     return wkt
 
@@ -328,18 +309,15 @@ def latlon_to_shp(lon, lat, shapefile):
 
     shapefile = str(shapefile)
 
-    schema = {'geometry': 'Point',
-              'properties': {'id': 'str'}}
+    schema = {"geometry": "Point", "properties": {"id": "str"}}
 
-    wkt = loads('POINT ({} {})'.format(lon, lat))
+    wkt = loads("POINT ({} {})".format(lon, lat))
 
-    with collection(shapefile, "w",
-                    crs=from_epsg(4326),
-                    driver="ESRI Shapefile",
-                    schema=schema) as output:
+    with collection(
+        shapefile, "w", crs=from_epsg(4326), driver="ESRI Shapefile", schema=schema
+    ) as output:
 
-        output.write({'geometry': mapping(wkt),
-                      'properties': {'id': '1'}})
+        output.write({"geometry": mapping(wkt), "properties": {"id": "1"}})
 
 
 def wkt_to_gdf(wkt):
@@ -353,41 +331,39 @@ def wkt_to_gdf(wkt):
     geometry = loads(wkt)
 
     # point wkt
-    if geometry.geom_type == 'Point':
-        data = {'id': ['1'], 'geometry': loads(wkt).buffer(0.05).envelope}
+    if geometry.geom_type == "Point":
+        data = {"id": ["1"], "geometry": loads(wkt).buffer(0.05).envelope}
         gdf = gpd.GeoDataFrame(data)
-    
+
     # polygon wkt
-    elif geometry.geom_type == 'Polygon':
-        data = {'id': ['1'], 'geometry': loads(wkt)}
-        gdf = gpd.GeoDataFrame(data, crs='epsg:4326')
+    elif geometry.geom_type == "Polygon":
+        data = {"id": ["1"], "geometry": loads(wkt)}
+        gdf = gpd.GeoDataFrame(data, crs="epsg:4326")
 
     # geometry collection of single multiploygon
     elif (
-            geometry.geom_type == 'GeometryCollection' and
-            len(geometry) == 1 and 'MULTIPOLYGON' in str(geometry)
+        geometry.geom_type == "GeometryCollection"
+        and len(geometry) == 1
+        and "MULTIPOLYGON" in str(geometry)
     ):
 
-        data = {'id': ['1'], 'geometry': geometry}
-        gdf = gpd.GeoDataFrame(data, crs='epsg:4326')
-        
+        data = {"id": ["1"], "geometry": geometry}
+        gdf = gpd.GeoDataFrame(data, crs="epsg:4326")
+
         ids, feats = [], []
         for i, feat in enumerate(gdf.geometry.values[0]):
             ids.append(i)
             feats.append(feat)
 
         gdf = gpd.GeoDataFrame(
-            {'id': ids, 'geometry': feats},
-            geometry='geometry',
-            crs=gdf.crs
+            {"id": ids, "geometry": feats}, geometry="geometry", crs=gdf.crs
         )
-    
+
     # geometry collection of single polygon
-    elif geometry.geom_type == 'GeometryCollection' and len(geometry) == 1:
-        
-        data = {'id': ['1'],
-                'geometry': geometry}
-        gdf = gpd.GeoDataFrame(data, crs='epsg:4326')
+    elif geometry.geom_type == "GeometryCollection" and len(geometry) == 1:
+
+        data = {"id": ["1"], "geometry": geometry}
+        gdf = gpd.GeoDataFrame(data, crs="epsg:4326")
 
     # everything else
     else:
@@ -398,18 +374,19 @@ def wkt_to_gdf(wkt):
             geoms.append(geom)
             i += 1
 
-        gdf = gpd.GeoDataFrame({'id': ids, 'geometry': geoms}, crs='epsg:4326')
-    
+        gdf = gpd.GeoDataFrame({"id": ids, "geometry": geoms}, crs="epsg:4326")
+
     return gdf
 
 
 def gdf_to_json_geometry(gdf):
-    """Function to parse features from GeoDataFrame in such a manner 
-       that rasterio wants them"""
+    """Function to parse features from GeoDataFrame in such a manner
+    that rasterio wants them"""
 
     geojson = json.loads(gdf.to_json())
-    return [feature['geometry'] for feature in geojson['features'] 
-            if feature['geometry']]
+    return [
+        feature["geometry"] for feature in geojson["features"] if feature["geometry"]
+    ]
 
 
 def exterior(infile, outfile, buffer=None):
@@ -420,7 +397,7 @@ def exterior(infile, outfile, buffer=None):
     :param buffer:
     :return:
     """
-    gdf = gpd.read_file(infile, crs='epsg:4326')
+    gdf = gpd.read_file(infile, crs="epsg:4326")
     gdf.geometry = gdf.geometry.apply(lambda row: Polygon(row.exterior))
     gdf_clean = gdf[gdf.geometry.area >= 1.0e-6]
 
@@ -430,30 +407,25 @@ def exterior(infile, outfile, buffer=None):
     # a negative buffer might polygons make disappear, so let's clean them
     gdf_clean = gdf_clean[~gdf_clean.geometry.is_empty]
 
-    gdf_clean.to_file(outfile, driver='GPKG')
+    gdf_clean.to_file(outfile, driver="GPKG")
 
 
 def difference(infile1, infile2, outfile):
 
     import warnings
-    warnings.filterwarnings(
-        'ignore', 'Geometry is in a geographic CRS', UserWarning
-    )
+
+    warnings.filterwarnings("ignore", "Geometry is in a geographic CRS", UserWarning)
 
     gdf1 = gpd.read_file(infile1)
     gdf2 = gpd.read_file(infile2)
 
-    gdf3 = gpd.overlay(gdf1, gdf2, how='difference')
+    gdf3 = gpd.overlay(gdf1, gdf2, how="difference")
 
     # remove slivers and artifacts
     gdf3 = gdf3.buffer(0)
     buffer = 0.00001
-    gdf3 = gdf3.buffer(
-        -buffer, 1, join_style=2
-    ).buffer(
-        buffer, 1, join_style=2
-    )
-    gdf3.to_file(outfile, driver='GeoJSON')
+    gdf3 = gdf3.buffer(-buffer, 1, join_style=2).buffer(buffer, 1, join_style=2)
+    gdf3.to_file(outfile, driver="GeoJSON")
 
 
 def set_subset(aoi, inventory_df):
@@ -462,10 +434,9 @@ def set_subset(aoi, inventory_df):
     aoi = loads(aoi)
 
     # burst_inventory case
-    if 'bid' in inventory_df.columns:
+    if "bid" in inventory_df.columns:
         for burst in inventory_df.bid.unique():
-            burst_geom = inventory_df.geometry[
-                inventory_df.bid == burst].unary_union
+            burst_geom = inventory_df.geometry[inventory_df.bid == burst].unary_union
             subset = True if aoi.within(burst_geom) else False
             if not subset:
                 return subset
@@ -474,7 +445,8 @@ def set_subset(aoi, inventory_df):
     else:
         for track in inventory_df.relativeorbit.unique():
             track_geom = inventory_df.geometry[
-                inventory_df.relativeorbit == track].unary_union
+                inventory_df.relativeorbit == track
+            ].unary_union
             subset = True if aoi.within(track_geom) else False
             if not subset:
                 return subset
@@ -486,19 +458,17 @@ def set_subset(aoi, inventory_df):
 def buffer_shape(infile, outfile, buffer=None):
 
     with collection(infile, "r") as in_shape:
-        schema = {'geometry': 'Polygon', 'properties': {'id': 'int'}}
+        schema = {"geometry": "Polygon", "properties": {"id": "int"}}
         crs = in_shape.crs
-        with collection(
-                outfile, "w", "ESRI Shapefile", schema, crs=crs) as output:
+        with collection(outfile, "w", "ESRI Shapefile", schema, crs=crs) as output:
 
             for i, point in enumerate(in_shape):
-                output.write({
-                    'properties': {
-                        'id': i
-                    },
-                    'geometry': mapping(
-                        shape(point['geometry']).buffer(buffer))
-                })
+                output.write(
+                    {
+                        "properties": {"id": i},
+                        "geometry": mapping(shape(point["geometry"]).buffer(buffer)),
+                    }
+                )
 
 
 def plot_inventory(aoi, inventory_df, transparency=0.05, annotate=False):
@@ -506,7 +476,7 @@ def plot_inventory(aoi, inventory_df, transparency=0.05, annotate=False):
     import matplotlib.pyplot as plt
 
     # load world borders for background
-    world = gpd.read_file(gpd.datasets.get_path('naturalearth_lowres'))
+    world = gpd.read_file(gpd.datasets.get_path("naturalearth_lowres"))
 
     # do the import of aoi as gdf
     aoi_gdf = wkt_to_gdf(aoi)
@@ -515,31 +485,32 @@ def plot_inventory(aoi, inventory_df, transparency=0.05, annotate=False):
     bounds = inventory_df.geometry.bounds
 
     # get world map as base
-    base = world.plot(color='lightgrey', edgecolor='white')
+    base = world.plot(color="lightgrey", edgecolor="white")
 
     # plot aoi
-    aoi_gdf.plot(ax=base, color='None', edgecolor='black')
+    aoi_gdf.plot(ax=base, color="None", edgecolor="black")
 
     # plot footprints
     inventory_df.plot(ax=base, alpha=transparency)
 
     # set bounds
-    plt.xlim([bounds.minx.min()-2, bounds.maxx.max()+2])
-    plt.ylim([bounds.miny.min()-2, bounds.maxy.max()+2])
-    plt.grid(color='grey', linestyle='-', linewidth=0.2)
+    plt.xlim([bounds.minx.min() - 2, bounds.maxx.max() + 2])
+    plt.ylim([bounds.miny.min() - 2, bounds.maxy.max() + 2])
+    plt.grid(color="grey", linestyle="-", linewidth=0.2)
     if annotate:
         import math
+
         for idx, row in inventory_df.iterrows():
             # print([row['geometry'].bounds[0],row['geometry'].bounds[3]])
-            coord = [row['geometry'].centroid.x, row['geometry'].centroid.y]
-            x1, y2, x2, y1 = row['geometry'].bounds
+            coord = [row["geometry"].centroid.x, row["geometry"].centroid.y]
+            x1, y2, x2, y1 = row["geometry"].bounds
             angle = math.degrees(math.atan2((y2 - y1), (x2 - x1)))
 
             plt.annotate(
-                s=row['bid'],
+                s=row["bid"],
                 xy=coord,
                 rotation=angle + 5,
                 size=10,
-                color='red',
-                horizontalalignment='center'
+                color="red",
+                horizontalalignment="center",
             )
